@@ -16,6 +16,7 @@ import contextlib
 import itertools
 import collections.abc
 
+from abc import ABC, abstractmethod
 
 try:
     import sqlite3
@@ -130,8 +131,8 @@ class UndoHandle:
 # for indexing
 
 
-class _IndexedSeqFileProxy:
-    """Base class for file format specific random access (PRIVATE).
+class _IndexedSeqFileProxy(ABC):
+    """Abstract base class for file format specific random access (PRIVATE).
 
     This is subclasses in both Bio.SeqIO for indexing as SeqRecord
     objects, and in Bio.SearchIO for indexing QueryResult objects.
@@ -140,19 +141,21 @@ class _IndexedSeqFileProxy:
     and optionally 'get_raw' methods.
     """
 
+    @abstractmethod
     def __iter__(self):
         """Return (identifier, offset, length in bytes) tuples.
 
         The length can be zero where it is not implemented or not
         possible for a particular file format.
         """
-        raise NotImplementedError("Subclass should implement this")
+        raise NotImplementedError
 
+    @abstractmethod
     def get(self, offset):
         """Return parsed object for this entry."""
         # Most file formats with self contained records can be handled by
         # parsing StringIO(self.get_raw(offset).decode())
-        raise NotImplementedError("Subclass should implement this")
+        raise NotImplementedError
 
     def get_raw(self, offset):
         """Return the raw record from the file as a bytes string (if implemented).
@@ -466,7 +469,6 @@ class _SQLiteManySeqFilesDict(_IndexedSeqFileDict):
             "INSERT INTO meta_data (key, value) VALUES (?,?);",
             ("filenames_relative_to_index", "True"),
         )
-        # TODO - Record the alphabet?
         # TODO - Record the file size and modified date?
         con.execute("CREATE TABLE file_data (file_number INTEGER, name TEXT);")
         con.execute(
